@@ -159,8 +159,12 @@ class FeatureExtractor:
         cr = ConfigReader(path_to_config)
         configs = cr.read()
 
-        self.path_to_root = os.path.join(CONST.ROOT, configs['PATH_TO_MVTS'])
-        self.path_to_output = os.path.join(CONST.ROOT, configs['PATH_TO_EXTRACTED_FEATURES'])
+        self.path_to_root = configs['PATH_TO_MVTS']
+        dirpath, _, all_csv = next(walk(self.path_to_root))
+        self.all_mvts_paths = [path.join(dirpath, f) for f in all_csv]  # absolute paths
+
+        # self.path_to_output = os.path.join(CONST.ROOT, configs['PATH_TO_EXTRACTED_FEATURES'])
+        self.path_to_output = configs['PATH_TO_EXTRACTED_FEATURES']
         self.statistical_features: list = configs['STATISTICAL_FEATURES']
         self.mvts_parameters: list = configs['MVTS_PARAMETERS']
         self.metadata_tags: list = configs['META_DATA_TAGS']
@@ -192,7 +196,7 @@ class FeatureExtractor:
         if first_k is not None:
             all_csv = all_csv[:first_k]
 
-        all_files = [path.join(dirpath, f) for f in all_csv]
+        all_files = [path.join(dirpath, f) for f in all_csv]  # absolute paths
 
         # ------------------------------------------------------------
         # partition the files to be distributed among processes.
@@ -315,7 +319,8 @@ class FeatureExtractor:
             all_csv_files = partition
 
         else:
-            _, _, all_csv_files = next(walk(self.path_to_root))
+            all_csv_files = self.all_mvts_paths
+            # _, _, all_csv_files = next(walk(self.path_to_root))
             if first_k is not None:
                 # Note: If `fist_k` was used in parallel version, it should have already been taken
                 # into account in `do_execution_in_parallel`. So, no need to do it again.
@@ -365,7 +370,8 @@ class FeatureExtractor:
                     sys.stdout.write("\r" + console_str)
                     sys.stdout.flush()
 
-            abs_path = path.join(self.path_to_root, f)
+            # abs_path = path.join(self.path_to_root, f)
+            abs_path = f
             df_mvts: pd.DataFrame = pd.read_csv(abs_path, sep='\t')
 
             # -----------------------------------------
